@@ -39,6 +39,18 @@ class cached_property(object):
         setattr(instance, self.f.__name__, value)
         return value
 
+def cached_function(func):
+    '''
+    Кешируемая функция
+    '''
+    def _func(*args, **kwargs):
+        try:
+            return _func._retval
+        except AttributeError:
+            _func._retval = func(*args, **kwargs)
+            return _func._retval
+    return _func
+
 def make_traceback(host):
     head = '%s | %s' % (host, datetime.datetime.now())
     line = '-' * len(head)
